Élenchos
********
A `Nagios <https://www.nagios.org/>`_ plugin framework in Python.

Documentation
*************
Documentation for developers who want to create Nagios plugins using Élenchos and the documentation for administrators
who want to install Nagios plugins build with Élenchos can be found at `elenchos.readthedocs.io <https://elenchos.readthedocs.io>`_.

License
*******
This project is licensed under the terms of the MIT license.
